==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_Error.h <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
#ifndef STUDIOWEB_ERROR_H
#define STUDIOWEB_ERROR_H

/*
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


/*!**********************************************************************

  module: StudioWeb_Error.h

  -----------------------------------------------------------------------

  mail to:  sapdb-general@sap.com

  special area: WebQuery

  description:  Error codes for webquery

  see also:

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000

************************************************************************/


/*----------------------------------------------------------------------------\
// Error Constants
//----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------\
// WQ_ERR001
//----------------------------------------------------------------------------*/
#define WQ_ERR001 "File already exits !"

/*----------------------------------------------------------------------------\
// WQ_ERR002
//----------------------------------------------------------------------------*/
#define WQ_ERR002 "No ODBC Driver!"

/*----------------------------------------------------------------------------\
// WQ_ERR003
//----------------------------------------------------------------------------*/
#define WQ_ERR003  "No more rows, cursor is closed !"

/*----------------------------------------------------------------------------\
// WQ_ERR004
//----------------------------------------------------------------------------*/
#define WQ_ERR004  "Error: get parameter values"

/*----------------------------------------------------------------------------\
// WQ_ERR005
//----------------------------------------------------------------------------*/
#define WQ_ERR005  "Error: getConnectParams"

/*----------------------------------------------------------------------------\
// WQ_ERR008
//----------------------------------------------------------------------------*/
#define WQ_ERR008  "Statements successfully executed, no result !" 

/*----------------------------------------------------------------------------\
// WQ_ERR009
//----------------------------------------------------------------------------*/
#define WQ_ERR009  "No valid connection object !" 

/*----------------------------------------------------------------------------\
// WQ_ERR010
//----------------------------------------------------------------------------*/
#define WQ_ERR010  "No session pool"

/*----------------------------------------------------------------------------\
// WQ_ERR012
//----------------------------------------------------------------------------*/
#define WQ_ERR012  "Error parsing: "

/*----------------------------------------------------------------------------\
// WQ_ERR013
//----------------------------------------------------------------------------*/
#define WQ_ERR013  "No Dbc Pool !"

/*----------------------------------------------------------------------------\
// WQ_ERR014
//----------------------------------------------------------------------------*/
#define WQ_ERR014  "Connection was down, and is reconnected !"

/*----------------------------------------------------------------------------\
// WQ_ERR015
//----------------------------------------------------------------------------*/
#define WQ_ERR015  "Connection is down"

/*----------------------------------------------------------------------------\
// WQ_ERR016
//----------------------------------------------------------------------------*/
#define WQ_ERR016  "Sorry, can not create Web Query session!"

/*----------------------------------------------------------------------------\
// WQ_ERR018
//----------------------------------------------------------------------------*/
#define WQ_ERR018 "Create DBC pool failed !"

/*----------------------------------------------------------------------------\
// WQ_ERR020
//----------------------------------------------------------------------------*/
#define WQ_ERR020 "No valid query string"

/*----------------------------------------------------------------------------\
// WQ_ERR021
//----------------------------------------------------------------------------*/
#define WQ_ERR021 "Method POST not used !"

/*----------------------------------------------------------------------------\
// WQ_ERR022
//----------------------------------------------------------------------------*/
#define WQ_ERR022 "GetWebSession failed, in dialog different to logon!"

/*----------------------------------------------------------------------------\
// WQ_ERR023
//----------------------------------------------------------------------------*/
#define WQ_ERR023 "Error reading odbcDriver Param !"

/*----------------------------------------------------------------------------\
// WQ_ERR024
//----------------------------------------------------------------------------*/
#define WQ_ERR024 "Missing database, user or password!"

/*----------------------------------------------------------------------------\
// WQ_ERR026
//----------------------------------------------------------------------------*/
#define WQ_ERR026 "No valid Stored Object !"

/*----------------------------------------------------------------------------\
// WQ_ERR027
//----------------------------------------------------------------------------*/
#define WQ_ERR027 "No valid path"

/*----------------------------------------------------------------------------\
// WQ_ERR028
//----------------------------------------------------------------------------*/
#define WQ_ERR028 "Sorry, your web query session timed out!"

/*----------------------------------------------------------------------------\
// WQ_ERR029
//----------------------------------------------------------------------------*/
#define WQ_ERR029 "No valid QueryTree object"

/*----------------------------------------------------------------------------\
// WQ_ERR030
//----------------------------------------------------------------------------*/
#define WQ_ERR030 "No valid Logout object"

/*----------------------------------------------------------------------------\
// WQ_ERR031
//----------------------------------------------------------------------------*/
#define WQ_ERR031 "No valid SQLWindow object"

/*----------------------------------------------------------------------------\
// WQ_ERR032
//----------------------------------------------------------------------------*/
#define WQ_ERR032 "No valid Result object"

/*----------------------------------------------------------------------------\
// WQ_ERR033
//----------------------------------------------------------------------------*/
#define WQ_ERR033 "No valid request"

/*----------------------------------------------------------------------------\
// WQ_ERR034
//----------------------------------------------------------------------------*/
#define WQ_ERR034 "No valid overwrite file value"

/*----------------------------------------------------------------------------\
// WQ_ERR035
//----------------------------------------------------------------------------*/
#define WQ_ERR035 "This Stored Object Type can't be saved !"

/*----------------------------------------------------------------------------\
// WQ_ERR036
//----------------------------------------------------------------------------*/
#define WQ_ERR036 "Invalid cursor position !"




#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_Error.h <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
#ifndef STUDIOWEB_ERROR_H
#define STUDIOWEB_ERROR_H

/*
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


/*!**********************************************************************

  module: StudioWeb_Error.h

  -----------------------------------------------------------------------

  mail to:  sapdb-general@sap.com

  special area: WebQuery

  description:  Error codes for webquery

  see also:

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000

************************************************************************/


/*----------------------------------------------------------------------------\
// Error Constants
//----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------\
// WQ_ERR001
//----------------------------------------------------------------------------*/
#define WQ_ERR001 "File already exits"

/*----------------------------------------------------------------------------\
// WQ_ERR002
//----------------------------------------------------------------------------*/
#define WQ_ERR002 "No ODBC Driver"

/*----------------------------------------------------------------------------\
// WQ_ERR003
//----------------------------------------------------------------------------*/
#define WQ_ERR003  "No more rows, cursor is closed"

/*----------------------------------------------------------------------------\
// WQ_ERR004
//----------------------------------------------------------------------------*/
#define WQ_ERR004  "Error: get parameter values"

/*----------------------------------------------------------------------------\
// WQ_ERR005
//----------------------------------------------------------------------------*/
#define WQ_ERR005  "Error: getConnectParams"

/*----------------------------------------------------------------------------\
// WQ_ERR008
//----------------------------------------------------------------------------*/
#define WQ_ERR008  "Statements successfully executed, no result" 

/*----------------------------------------------------------------------------\
// WQ_ERR009
//----------------------------------------------------------------------------*/
#define WQ_ERR009  "No valid connection object" 

/*----------------------------------------------------------------------------\
// WQ_ERR010
//----------------------------------------------------------------------------*/
#define WQ_ERR010  "No session pool"

/*----------------------------------------------------------------------------\
// WQ_ERR012
//----------------------------------------------------------------------------*/
#define WQ_ERR012  "Error parsing: "

/*----------------------------------------------------------------------------\
// WQ_ERR013
//----------------------------------------------------------------------------*/
#define WQ_ERR013  "No Dbc Pool"

/*----------------------------------------------------------------------------\
// WQ_ERR014
//----------------------------------------------------------------------------*/
#define WQ_ERR014  "Connection was down, and is reconnected"

/*----------------------------------------------------------------------------\
// WQ_ERR015
//----------------------------------------------------------------------------*/
#define WQ_ERR015  "Connection is down"

/*----------------------------------------------------------------------------\
// WQ_ERR016
//----------------------------------------------------------------------------*/
#define WQ_ERR016  "Sorry, can not create WebSQL session"

/*----------------------------------------------------------------------------\
// WQ_ERR017
//----------------------------------------------------------------------------*/
#define WQ_ERR017  "Sorry, can not create WebSQL object"

/*----------------------------------------------------------------------------\
// WQ_ERR018
//----------------------------------------------------------------------------*/
#define WQ_ERR018 "Create DBC pool failed"

/*----------------------------------------------------------------------------\
// WQ_ERR019
//----------------------------------------------------------------------------*/
#define WQ_ERR019 "Invalid Session ID"

/*----------------------------------------------------------------------------\
// WQ_ERR020
//----------------------------------------------------------------------------*/
#define WQ_ERR020 "No valid query string"

/*----------------------------------------------------------------------------\
// WQ_ERR021
//----------------------------------------------------------------------------*/
#define WQ_ERR021 "Crypted password string is too short"

/*----------------------------------------------------------------------------\
// WQ_ERR022
//----------------------------------------------------------------------------*/
#define WQ_ERR022 "GetWebSession failed, in dialog different to logon"

/*----------------------------------------------------------------------------\
// WQ_ERR023
//----------------------------------------------------------------------------*/
#define WQ_ERR023 "Error reading odbcDriver Param"

/*----------------------------------------------------------------------------\
// WQ_ERR024
//----------------------------------------------------------------------------*/
#define WQ_ERR024 "Missing database, user or password"

/*----------------------------------------------------------------------------\
// WQ_ERR026
//----------------------------------------------------------------------------*/
#define WQ_ERR026 "No valid Stored Object"

/*----------------------------------------------------------------------------\
// WQ_ERR027
//----------------------------------------------------------------------------*/
#define WQ_ERR027 "No valid path"

/*----------------------------------------------------------------------------\
// WQ_ERR028
//----------------------------------------------------------------------------*/
#define WQ_ERR028 "Sorry, your WebSQL session timed out"

/*----------------------------------------------------------------------------\
// WQ_ERR029
//----------------------------------------------------------------------------*/
#define WQ_ERR029 "No valid QueryTree object"

/*----------------------------------------------------------------------------\
// WQ_ERR030
//----------------------------------------------------------------------------*/
#define WQ_ERR030 "No valid Logout object"

/*----------------------------------------------------------------------------\
// WQ_ERR031
//----------------------------------------------------------------------------*/
#define WQ_ERR031 "No valid SQLWindow object"

/*----------------------------------------------------------------------------\
// WQ_ERR032
//----------------------------------------------------------------------------*/
#define WQ_ERR032 "No valid Result object"

/*----------------------------------------------------------------------------\
// WQ_ERR033
//----------------------------------------------------------------------------*/
#define WQ_ERR033 "No valid request"

/*----------------------------------------------------------------------------\
// WQ_ERR034
//----------------------------------------------------------------------------*/
#define WQ_ERR034 "No valid overwrite file value"

/*----------------------------------------------------------------------------\
// WQ_ERR035
//----------------------------------------------------------------------------*/
#define WQ_ERR035 "This Stored Object Type can't be saved"

/*----------------------------------------------------------------------------\
// WQ_ERR036
//----------------------------------------------------------------------------*/
#define WQ_ERR036 "Invalid cursor position"

/*----------------------------------------------------------------------------\
// WQ_ERR037
//----------------------------------------------------------------------------*/
#define WQ_ERR037 "Can not set WebSQL session data"

/*----------------------------------------------------------------------------\
// WQ_ERR038
//----------------------------------------------------------------------------*/
#define WQ_ERR038 "Crypted user string is too short"

/*----------------------------------------------------------------------------\
// WQ_ERR039
//----------------------------------------------------------------------------*/
#define WQ_ERR039 "Error uncrypting password"

/*----------------------------------------------------------------------------\
// WQ_ERR040
//----------------------------------------------------------------------------*/
#define WQ_ERR040 "Error uncrypting user"

#endif
